==> RSTouchscreenNG-1.4.1.zip: RSTouchscreenNG/projects/pages/src/lib/dashboard.component.ts <==
/* (C) 2016-2021 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Component, OnDestroy} from "@angular/core";
import {
  PrintersState, PrinterState, ServerState, WifiState, MessageState, ExternalCommand, MessagesAction, WebCall,
  GPIO, PrinterAction, ExternalLink, ServerAction, RepetierState
} from "binding";
import {Observable, SubscriptionLike} from "rxjs";
import {RSModal, RSUIHelper} from "front-ui";
import {Router} from "@angular/router";
import {Store} from "@ngrx/store";

@Component({
  selector: "rs-dashboard",
  template: `
<rs-page [nameSwitchable]="false">
<rs-side>
    <rs-sideicon *ngIf="printers?.active && server.serverFolders?.length; else elseHome" title="<?php _('Import') ?>" icon="rs rs-usbstick" link="/import"></rs-sideicon>
    <ng-template #elseHome><rs-sideicon title="<?php _('Home') ?>" icon="fa fa-home" link="/"></rs-sideicon></ng-template>
</rs-side>
<rs-side *rsIfConnected="true">
    <rs-sideicon *rsIfPrinting="true" title="<?php _('Print') ?>" icon="rs rs-print" link="/print-status"></rs-sideicon>
    <rs-sideicon *rsIfPrinting="false" icon="rs rs-move-xy" title="<?php _('Move') ?>" link="/move-tool"></rs-sideicon>
</rs-side>
<rs-side *rsIfConnected="false">
    <rs-sideicon icon="rs rs-printer" title="<?php _('Printers') ?>" link="/printer-list"></rs-sideicon>
</rs-side>
<rs-side>
    <rs-sideicon *rsIfConnected="true" icon="rs rs-params" title="<?php _('Status') ?>" link="/params"></rs-sideicon>
    <rs-sideicon *rsIfConnected="false" icon="fa fa-gear" title="<?php _('Settings') ?>" link="/settings"></rs-sideicon>
</rs-side>
<main>
    <rs-headline [nameSwitchable]="false" *ngIf="printers.active"><span (rsClick)="goPrinterList()"><i class="fa fa-home"></i> {{printers.printers[printers.active].name}}</span></rs-headline>
    <rs-headline [nameSwitchable]="false" *ngIf="!(printers.active)"><span (rsClick)="goPrinterList()"><i class="fa fa-home"></i> <?php _('No Printer Selected') ?></span></rs-headline>
    <div class="content-h1" rsDrag>
    <div class="margin-leftright" *ngIf="(server$|async).diskUsage?.usage && (server$|async).diskUsage?.available < 1000000000">
      <rs-progress [value]="(server$|async).diskUsage?.usage" [type]="(server$|async).diskUsage?.classname" text="<?php _('Free Disk Space') ?>: {{(server$|async).diskUsage?.available | byte}}"></rs-progress>
    </div>
    <div class="alert error margin-leftright" *ngIf="printer && printer?.recover.state>=2 && printer?.recover.state<=4">
      <?php _('Last print job did not finish. Starting any new job will void this information and make a rescue impossible!') ?>
      <rs-button  class="error" (hit)="goRescue()">
            <i class="rs rs-print"></i>
            <h3 class="text" style="padding:2px 8px;margin:0"><?php _('Rescue Print') ?></h3></rs-button>
    </div>

    <rs-iconlist>
        <rs-icon *ngIf="printers?.active" icon="rs rs-file-gcode" title="<?php _('G-Codes') ?>" link="/gcodes"></rs-icon>
        <rs-icon *ngIf="printers?.active && printer?.config?.general?.enableQueue && (printers.printers[printers.active].queue?.length>0)" [counter]="printers.printers[printers.active].queue?.length" icon="rs rs-queue" title="{{tPrintQueue}}" link="/print-queue"></rs-icon>
        <rs-icon *rsIfConnected="true" icon="rs rs-move-xy" title="<?php _('Move') ?>" link="/move-tool"></rs-icon>
        <rs-icon *ngIf="printer?.online===1 && printer?.config?.extruders?.length>0" [icon]="printerAction.extruderChangeIcon(printer.slug,printer.activeExtruderId)" [title]="printerAction.extruderChangeName(printer.slug,printer.activeExtruderId)" link="/changefilament"></rs-icon>
        <rs-icon icon="rs rs-printer" title="<?php _('Printers') ?>" link="/printer-list"></rs-icon>
        <!-- <rs-icon icon="fa fa-sitemap" title="<?php _('Network') ?>" link="/network"></rs-icon> -->
        <rs-icon *rsIfPrinting="true" icon="rs rs-print" title="<?php _('Print') ?>" link="/print-status"></rs-icon>
        <rs-icon *rsIfConnected="true" icon="rs rs-params" title="<?php _('Status') ?>" link="/params"></rs-icon>
        <rs-icon *ngIf="printers?.active && server.serverFolders?.length" icon="rs rs-usbstick" title="<?php _('Import') ?>" link="/import"></rs-icon>
        <rs-icon *rsIfConnected="true" icon="rs rs-printer-commands" title="<?php _('Console') ?>" link="/console"></rs-icon>
        <rs-icon *ngIf="printer?.config?.quickCommands?.length && printer.online===1" icon="rs rs-printer-commands" title="{{tPrinterCmds}}" link="/printer-commands"></rs-icon>
        <rs-icon *ngIf="printer?.config?.wizardCommands?.length && printer.online===1" icon="fa fa-magic" title="{{tWizards}}" link="/wizards"></rs-icon>
        <rs-icon *ngIf="webCallFiltered.length>0" icon="fa fa-globe" title="<?php _('Web Actions') ?>" link="/web-actions"></rs-icon>
        <rs-icon *ngIf="gpioFiltered.length>0" icon="rs rs-gpio" title="<?php _('GPIO') ?>" link="/gpio-actions"></rs-icon>
        <rs-icon icon="fa fa-server" title="<?php _('Server Cmds.') ?>" link="/server-commands" *ngIf="(server$ | async).externalCommands.length"></rs-icon>
        <!-- <rs-icon *ngIf="(wifi$ | async).manageable" icon="fa fa-wifi" title="<?php _('WLAN') ?>" link="/wlan"></rs-icon> -->
        <!-- <rs-icon *rsIfConnected="true" icon="rs rs-move-z" title="<?php _('Z Move') ?>" link="/move-z-tool"></rs-icon>
        <rs-icon *rsIfConnected="true" icon="rs rs-extruder" title="<?php _('Extruder') ?>" link="/move-e-tool"></rs-icon> -->
        <rs-icon *rsIfConnected="true" icon="rs rs-chart" title="<?php _('Temp. Graph') ?>" link="/temperatures"></rs-icon>
        <!-- <rs-icon icon="fa fa-language" title="<?php _('Language') ?>" link="/languages"></rs-icon> -->
        <rs-icon *ngIf="!wideScreen" icon="fa fa-envelope" title="<?php _('Messages') ?>" link="/messages" [counter]="(messages$|async).length"></rs-icon>
        <rs-icon *ngIf="printer?.config?.webcams?.length>0" icon="rs rs-webcam" title="<?php _('Webcam') ?>" link="/webcam"></rs-icon>
        <rs-icon *ngIf="printer?.config?.webcams?.length>0" icon="rs rs-timelapse" title="<?php _('Timelapse') ?>" link="/timelapse"></rs-icon>
        <rs-icon *ngFor="let f of externalLinksFiltered" [icon]="f.icon?f.icon:'fa fa-external-link'" [title]="f.title" (rsClick)="runExternalLink(f)"></rs-icon>
        <rs-icon icon="fa fa-lock" title="<?php _('Lock Screen') ?>" *ngIf="server.settings['frontSetting'] && server.settings['frontSetting'].unlockPin !== ''" link="/unlock"></rs-icon>
        <!-- <rs-icon icon="rs rs-screensaver" title="<?php _('Screensaver') ?>" link="/screensaver"></rs-icon> -->
        <rs-icon *ngIf="server?.hardwareInfoMaxUrgency>-1" icon="{{server?.hardwareInfoIcon}}" title="<?php _('Hardware Info') ?>" link="/hardware-info"></rs-icon>
        <rs-icon icon="fa fa-gear" title="<?php _('Settings') ?>" link="/settings"></rs-icon>
        <rs-icon icon="fa fa-refresh" title="<?php _('Restart UI') ?>" (rsClick)="restart()"></rs-icon>
        <rs-icon *ngIf="shutdown" [icon]="(shutdown.icon ? shutdown.icon : 'fa fa-power-off')" title="<?php _('Shutdown') ?>" (rsClick)="runCommand(shutdown)"></rs-icon>
    </rs-iconlist>
    </div>
</main>
</rs-page>`
})
export class DashboardComponent implements OnDestroy {
  printers$: Observable<PrintersState>;
  server$: Observable<ServerState>;
  wifi$: Observable<WifiState>;
  messages$: Observable<MessageState[]>;
  commands$: Observable<ExternalCommand[]>;
  externalLinks$: Observable<ExternalLink[]>;
  printer: PrinterState;
  printers: PrintersState;
  lastSlug = '';
  server: ServerState = undefined;
  shutdown: ExternalCommand = null;
  private printersSubscription: SubscriptionLike;
  private serverSubscription: SubscriptionLike;
  private commandsSubscription: SubscriptionLike;
  private externalLinksSubscription: SubscriptionLike;
  wideScreen: Boolean = false;
  tPrintQueue = "<?php _('Print Queue') ?>";
  tPrinterCmds = "<?php _('Printer Cmds.') ?>";
  tWizards = "<?php _('Wizards') ?>";
  webCalls$: Observable<WebCall[]>;
  private webCallsSubscription: SubscriptionLike;
  webCallFiltered: WebCall[] = [];
  externalLinksFiltered: ExternalLink[];
  gpios$: Observable<GPIO[]>;
  private gpioSubscription: SubscriptionLike;
  gpioFiltered: GPIO[] = [];

  constructor(public ui: RSUIHelper,
              public printerAction: PrinterAction,
              public serverAction: ServerAction,
              public modal: RSModal,
              public messagesAction: MessagesAction, // initializes fetching
              public router: Router,
              private store: Store<RepetierState>
  ) {
    this.printers$ = store.select('printers');
    this.server$ = store.select('server');
    this.wifi$ = store.select('wifi');
    this.messages$ = store.select('messages');
    this.commands$ = store.select((state) => state.server.externalCommands);
    this.webCalls$ = store.select((state) => state.server.webCalls);
    this.gpios$ = store.select((state) => state.server.gpios);
    this.externalLinks$ = store.select((state) => state.server.externalLinks);
    this.wideScreen = window.outerWidth >= 800;
    this.printersSubscription = this.printers$.subscribe((p: PrintersState) => {
      this.printers = p;
      if (p.active) {
        this.printer = p.printers[p.active];
      } else {
        this.printer = undefined;
      }
      if (this.lastSlug !== p.active) {
        this.lastSlug = p.active;
        this.updateLinks();

      }
    });
    this.serverSubscription = this.server$.subscribe((s: ServerState) => {
      this.server = s;
    });
    this.commandsSubscription = this.commands$.subscribe((c: ExternalCommand[]) => {
      c.forEach(x => {
        if (x.execute.indexOf("shutdown -h") >= 0) {
          this.shutdown = x;
        }
      });
    });
    this.webCallsSubscription = this.webCalls$.subscribe((w: WebCall[]) => {
      const a: WebCall[] = [];
      w.forEach(x => {
        if (x.show_in_menu && ((this.printer && x.slug === this.printer.slug) || x.slug === '')) {
          a.push(x);
        }
      });
      this.webCallFiltered = a;
    });
    this.externalLinksSubscription = this.externalLinks$.subscribe((w: ExternalLink[]) => {
      this.updateLinks();
    });
    this.gpioSubscription = this.gpios$.subscribe((w: GPIO[]) => {
      const a: GPIO[] = [];
      w.forEach(x => {
        if (x.showInMenu && ((this.printer && x.slug === this.printer.slug) || x.slug === '')) {
          a.push(x);
        }
      });
      this.gpioFiltered = a;
    });
  }

  updateLinks () {
    const a: ExternalLink[] = [];
    if (this.server && this.server.externalLinks) {
      this.server.externalLinks.forEach(x => {
        if (x.touchscreen && ((this.printer && x.slug === this.printer.slug) || x.slug === '')) {
          a.push(x);
        }
      });
    }
    this.externalLinksFiltered = a;
  }

  ngOnDestroy() {
    this.gpioSubscription.unsubscribe();
    this.webCallsSubscription.unsubscribe();
    this.printersSubscription.unsubscribe();
    this.serverSubscription.unsubscribe();
    this.commandsSubscription.unsubscribe();
    this.externalLinksSubscription.unsubscribe();
  }

  restart() {
    window.location.assign(window.location.pathname + "?front=1&" + Math.random());
  }
  runExternalLink(l: ExternalLink) {
      this.router.navigate(['/external-link/' + l.id], { });
  }
  runCommand(cmd: ExternalCommand) {
    if (cmd.confirm) {
      this.modal.confirm("<?php _('Security Question') ?>", cmd.confirm, {}).then(
        (res) => this.serverAction.runExternalCommand(cmd), () => {
        }
      );
    } else {
      this.serverAction.runExternalCommand(cmd);
    }
  }

  goRescue(): void {
    this.router.navigateByUrl("/rescue");
  }

  goPrinterList(): void {
    this.ui.selectPrinter();
    // this.router.navigateByUrl("/printer-list");
  }

}

==> RSTouchscreenNG-1.4.5.zip: RSTouchscreenNG/projects/pages/src/lib/dashboard.component.ts <==
/* (C) 2016-2023 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Component, OnDestroy} from "@angular/core";
import {
  PrintersState, PrinterState, ServerState, WifiState, MessageState, ExternalCommand, MessagesAction, WebCall,
  GPIO, PrinterAction, ExternalLink, ServerAction, RepetierState
} from "binding";
import {Observable, SubscriptionLike} from "rxjs";
import {RSModal, RSUIHelper} from "front-ui";
import {Router} from "@angular/router";
import {Store} from "@ngrx/store";

@Component({
  // eslint-disable-next-line @angular-eslint/component-selector
  selector: "rs-dashboard",
  template: `
<rs-page [nameSwitchable]="false">
<rs-side>
    <rs-sideicon *ngIf="printers?.active && server.serverFolders?.length; else elseHome" title="<?php _('Import') ?>" icon="rs rs-usbstick" link="/import"></rs-sideicon>
    <ng-template #elseHome><rs-sideicon title="<?php _('Home') ?>" icon="fa fa-home" link="/"></rs-sideicon></ng-template>
</rs-side>
<rs-side *rsIfConnected="true">
    <rs-sideicon *rsIfPrinting="true" title="<?php _('Print') ?>" icon="rs rs-print" link="/print-status"></rs-sideicon>
    <rs-sideicon *rsIfPrinting="false" icon="rs rs-move-xy" title="<?php _('Move') ?>" link="/move-tool"></rs-sideicon>
</rs-side>
<rs-side *rsIfConnected="false">
    <rs-sideicon icon="rs rs-printer" title="<?php _('Printers') ?>" link="/printer-list"></rs-sideicon>
</rs-side>
<rs-side>
    <rs-sideicon *rsIfConnected="true" icon="rs rs-params" title="<?php _('Status') ?>" link="/params"></rs-sideicon>
    <rs-sideicon *rsIfConnected="false" icon="fa fa-gear" title="<?php _('Settings') ?>" link="/settings"></rs-sideicon>
</rs-side>
<main>
    <rs-headline [nameSwitchable]="false" *ngIf="printers.active"><span (rsClick)="goPrinterList()"><i class="fa fa-home"></i> {{printers.printers[printers.active].name}}</span></rs-headline>
    <rs-headline [nameSwitchable]="false" *ngIf="!(printers.active)"><span (rsClick)="goPrinterList()"><i class="fa fa-home"></i> <?php _('No Printer Selected') ?></span></rs-headline>
    <div class="content-h1" rsDrag>
    <div class="margin-leftright" *ngIf="(server$|async).diskUsage?.usage && (server$|async).diskUsage?.available < 1000000000">
      <rs-progress [value]="(server$|async).diskUsage?.usage" [type]="(server$|async).diskUsage?.classname" text="<?php _('Free Disk Space') ?>: {{(server$|async).diskUsage?.available | byte}}"></rs-progress>
    </div>
    <div class="alert error margin-leftright" *ngIf="printer && printer?.recover.state>=2 && printer?.recover.state<=4">
      <?php _('Last print job did not finish. Starting any new job will void this information and make a rescue impossible!') ?>
      <rs-button  class="error" (hit)="goRescue()">
            <i class="rs rs-print"></i>
            <h3 class="text" style="padding:2px 8px;margin:0"><?php _('Rescue Print') ?></h3></rs-button>
    </div>

    <rs-iconlist>
        <rs-icon *ngIf="printers?.active" icon="rs rs-file-gcode" title="<?php _('G-Codes') ?>" link="/gcodes"></rs-icon>
        <rs-icon *ngIf="printers?.active && printer?.config?.general?.enableQueue && (printers.printers[printers.active].queue?.length>0)" [counter]="printers.printers[printers.active].queue?.length" icon="rs rs-queue" title="{{tPrintQueue}}" link="/print-queue"></rs-icon>
        <rs-icon *rsIfConnected="true" icon="rs rs-move-xy" title="<?php _('Move') ?>" link="/move-tool"></rs-icon>
        <rs-icon *ngIf="printer?.online===1 && printer?.config?.extruders?.length>0" [icon]="printerAction.extruderChangeIcon(printer.slug,printer.activeExtruderId)" [title]="printerAction.extruderChangeName(printer.slug,printer.activeExtruderId)" link="/changefilament"></rs-icon>
        <rs-icon icon="rs rs-printer" title="<?php _('Printers') ?>" link="/printer-list"></rs-icon>
        <!-- <rs-icon icon="fa fa-sitemap" title="<?php _('Network') ?>" link="/network"></rs-icon> -->
        <rs-icon *rsIfPrinting="true" icon="rs rs-print" title="<?php _('Print') ?>" link="/print-status"></rs-icon>
        <rs-icon *rsIfConnected="true" icon="rs rs-params" title="<?php _('Status') ?>" link="/params"></rs-icon>
        <rs-icon *ngIf="printers?.active && server.serverFolders?.length" icon="rs rs-usbstick" title="<?php _('Import') ?>" link="/import"></rs-icon>
        <rs-icon *rsIfConnected="true" icon="rs rs-printer-commands" title="<?php _('Console') ?>" link="/console"></rs-icon>
        <rs-icon *ngIf="printer?.config?.quickCommands?.length && printer.online===1" icon="rs rs-printer-commands" title="{{tPrinterCmds}}" link="/printer-commands"></rs-icon>
        <rs-icon *ngIf="printer?.config?.wizardCommands?.length && printer.online===1" icon="fa fa-magic" title="{{tWizards}}" link="/wizards"></rs-icon>
        <rs-icon *ngIf="webCallFiltered.length>0" icon="fa fa-globe" title="<?php _('Web Actions') ?>" link="/web-actions"></rs-icon>
        <rs-icon *ngIf="gpioFiltered.length>0" icon="rs rs-gpio" title="<?php _('GPIO') ?>" link="/gpio-actions"></rs-icon>
        <rs-icon icon="fa fa-server" title="<?php _('Server Cmds.') ?>" link="/server-commands" *ngIf="(server$ | async).externalCommands.length"></rs-icon>
        <!-- <rs-icon *ngIf="(wifi$ | async).manageable" icon="fa fa-wifi" title="<?php _('WLAN') ?>" link="/wlan"></rs-icon> -->
        <!-- <rs-icon *rsIfConnected="true" icon="rs rs-move-z" title="<?php _('Z Move') ?>" link="/move-z-tool"></rs-icon>
        <rs-icon *rsIfConnected="true" icon="rs rs-extruder" title="<?php _('Extruder') ?>" link="/move-e-tool"></rs-icon> -->
        <rs-icon *rsIfConnected="true" icon="rs rs-chart" title="<?php _('Temp. Graph') ?>" link="/temperatures"></rs-icon>
        <!-- <rs-icon icon="fa fa-language" title="<?php _('Language') ?>" link="/languages"></rs-icon> -->
        <rs-icon *ngIf="!wideScreen" icon="fa fa-envelope" title="<?php _('Messages') ?>" link="/messages" [counter]="(messages$|async).length"></rs-icon>
        <rs-icon *ngIf="printer?.config?.webcams?.length>0" icon="rs rs-webcam" title="<?php _('Webcam') ?>" link="/webcam"></rs-icon>
        <rs-icon *ngIf="printer?.config?.webcams?.length>0" icon="rs rs-timelapse" title="<?php _('Timelapse') ?>" link="/timelapse"></rs-icon>
        <rs-icon *ngFor="let f of externalLinksFiltered" [icon]="f.icon?f.icon:'fa fa-external-link'" [title]="f.title" (rsClick)="runExternalLink(f)"></rs-icon>
        <rs-icon icon="fa fa-lock" title="<?php _('Lock Screen') ?>" *ngIf="server.settings['frontSetting'] && server.settings['frontSetting'].unlockPin !== ''" link="/unlock"></rs-icon>
        <!-- <rs-icon icon="rs rs-screensaver" title="<?php _('Screensaver') ?>" link="/screensaver"></rs-icon> -->
        <rs-icon *ngIf="server?.hardwareInfoMaxUrgency>-1" icon="{{server?.hardwareInfoIcon}}" title="<?php _('Hardware Info') ?>" link="/hardware-info"></rs-icon>
        <rs-icon icon="fa fa-gear" title="<?php _('Settings') ?>" link="/settings"></rs-icon>
        <rs-icon icon="fa fa-refresh" title="<?php _('Restart UI') ?>" (rsClick)="restart()"></rs-icon>
        <rs-icon *ngIf="shutdown" [icon]="(shutdown.icon ? shutdown.icon : 'fa fa-power-off')" title="<?php _('Shutdown') ?>" (rsClick)="runCommand(shutdown)"></rs-icon>
    </rs-iconlist>
    </div>
</main>
</rs-page>`
})
export class DashboardComponent implements OnDestroy {
  printers$: Observable<PrintersState>;
  server$: Observable<ServerState>;
  wifi$: Observable<WifiState>;
  messages$: Observable<MessageState[]>;
  commands$: Observable<ExternalCommand[]>;
  externalLinks$: Observable<ExternalLink[]>;
  printer: PrinterState;
  printers: PrintersState;
  lastSlug = '';
  server: ServerState = undefined;
  shutdown: ExternalCommand = null;
  private printersSubscription: SubscriptionLike;
  private serverSubscription: SubscriptionLike;
  private commandsSubscription: SubscriptionLike;
  private externalLinksSubscription: SubscriptionLike;
  wideScreen: Boolean = false;
  tPrintQueue = "<?php _('Print Queue') ?>";
  tPrinterCmds = "<?php _('Printer Cmds.') ?>";
  tWizards = "<?php _('Wizards') ?>";
  webCalls$: Observable<WebCall[]>;
  private webCallsSubscription: SubscriptionLike;
  webCallFiltered: WebCall[] = [];
  externalLinksFiltered: ExternalLink[];
  gpios$: Observable<GPIO[]>;
  private gpioSubscription: SubscriptionLike;
  gpioFiltered: GPIO[] = [];

  constructor(public ui: RSUIHelper,
              public printerAction: PrinterAction,
              public serverAction: ServerAction,
              public modal: RSModal,
              public messagesAction: MessagesAction, // initializes fetching
              public router: Router,
              private store: Store<RepetierState>
  ) {
    this.printers$ = store.select('printers');
    this.server$ = store.select('server');
    this.wifi$ = store.select('wifi');
    this.messages$ = store.select('messages');
    this.commands$ = store.select((state) => state.server.externalCommands);
    this.webCalls$ = store.select((state) => state.server.webCalls);
    this.gpios$ = store.select((state) => state.server.gpios);
    this.externalLinks$ = store.select((state) => state.server.externalLinks);
    this.wideScreen = window.outerWidth >= 800;
    this.printersSubscription = this.printers$.subscribe((p: PrintersState) => {
      this.printers = p;
      if (p.active) {
        this.printer = p.printers[p.active];
      } else {
        this.printer = undefined;
      }
      if (this.lastSlug !== p.active) {
        this.lastSlug = p.active;
        this.updateLinks();

      }
    });
    this.serverSubscription = this.server$.subscribe((s: ServerState) => {
      this.server = s;
    });
    this.commandsSubscription = this.commands$.subscribe((c: ExternalCommand[]) => {
      c.forEach(x => {
        if (x.execute.indexOf("shutdown -h") >= 0) {
          this.shutdown = x;
        }
      });
    });
    this.webCallsSubscription = this.webCalls$.subscribe((w: WebCall[]) => {
      const a: WebCall[] = [];
      w.forEach(x => {
        if (x.show_in_menu && ((this.printer && x.slug === this.printer.slug) || x.slug === '')) {
          a.push(x);
        }
      });
      this.webCallFiltered = a;
    });
    this.externalLinksSubscription = this.externalLinks$.subscribe((/* w: ExternalLink[] */) => {
      this.updateLinks();
    });
    this.gpioSubscription = this.gpios$.subscribe((w: GPIO[]) => {
      const a: GPIO[] = [];
      w.forEach(x => {
        if (x.showInMenu && ((this.printer && x.slug === this.printer.slug) || x.slug === '')) {
          a.push(x);
        }
      });
      this.gpioFiltered = a;
    });
  }

  updateLinks () {
    const a: ExternalLink[] = [];
    if (this.server && this.server.externalLinks) {
      this.server.externalLinks.forEach(x => {
        if (x.touchscreen && ((this.printer && x.slug === this.printer.slug) || x.slug === '')) {
          a.push(x);
        }
      });
    }
    this.externalLinksFiltered = a;
  }

  ngOnDestroy() {
    this.gpioSubscription.unsubscribe();
    this.webCallsSubscription.unsubscribe();
    this.printersSubscription.unsubscribe();
    this.serverSubscription.unsubscribe();
    this.commandsSubscription.unsubscribe();
    this.externalLinksSubscription.unsubscribe();
  }

  restart() {
    window.location.assign(window.location.pathname + "?front=1&" + Math.random());
  }
  runExternalLink(l: ExternalLink) {
      this.router.navigate(['/external-link/' + l.id], { });
  }
  runCommand(cmd: ExternalCommand) {
    if (cmd.confirm) {
      this.modal.confirm("<?php _('Security Question') ?>", cmd.confirm, {}).then(
        (/*res*/) => this.serverAction.runExternalCommand(cmd), () => {
        }
      );
    } else {
      this.serverAction.runExternalCommand(cmd);
    }
  }

  goRescue(): void {
    this.router.navigateByUrl("/rescue");
  }

  goPrinterList(): void {
    this.ui.selectPrinter();
    // this.router.navigateByUrl("/printer-list");
  }

}
